@@ -6,9 +6,11 @@ OC.L10N.register(
     "Allowed (Inherited permission)" : "Atļauts (Mantota atļauja)",
     "Denied" : "Liegts",
     "Allowed" : "Atļauts",
+    "Access denied" : "Piekļuve liegta",
     "Deny" : "Noraidīt",
     "Allow" : "Atļaut",
     "Group" : "Grupa",
+    "Team" : "Komanda",
     "Read" : "Lasīt",
     "Write" : "Rakstīt",
     "Create" : "Izveidot",
